==> seedsui-react-2.6.2.tgz: package/es/Container/Container.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ImgLazy from './../ImgLazy';

var Container = function (_Component) {
  _inherits(Container, _Component);

  function Container(props) {
    _classCallCheck(this, Container);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {
      lazyLoadInstance: null
    };
    return _this;
  }

  Container.prototype.componentDidMount = function componentDidMount() {
    if (this.props.lazyLoad) {
      var imglazy = new ImgLazy({
        overflowContainer: this.$el
      });
      imglazy.load();
      this.setState({
        lazyLoadInstance: imglazy
      });
    }
  };

  Container.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        style = _props.style,
        className = _props.className,
        lazyLoad = _props.lazyLoad,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['style', 'className', 'lazyLoad', 'children']);

    return React.createElement(
      'article',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        }, className: 'container' + (className ? ' ' + className : ''), style: style }, others),
      children
    );
  };

  return Container;
}(Component);

export { Container as default };
Container.propTypes = process.env.NODE_ENV !== "production" ? {
  style: PropTypes.object,
  className: PropTypes.string,
  lazyLoad: PropTypes.bool,
  children: PropTypes.node
} : {};

==> seedsui-react-3.0.4.tgz: package/es/Container/Container.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ImgLazy from './../ImgLazy';

var Container = function (_Component) {
  _inherits(Container, _Component);

  function Container(props) {
    _classCallCheck(this, Container);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Container.prototype.componentDidMount = function componentDidMount() {
    if (this.props.lazyLoad) {
      this.lazyLoadInstance = new ImgLazy({
        overflowContainer: this.$el
      });
      this.lazyLoadInstance.load();
    }
  };

  Container.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        lazyLoad = _props.lazyLoad,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['lazyLoad', 'children']);

    return React.createElement(
      'article',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'container' + (others.className ? ' ' + others.className : '') }),
      children
    );
  };

  return Container;
}(Component);

export { Container as default };
Container.propTypes = process.env.NODE_ENV !== "production" ? {
  lazyLoad: PropTypes.bool,
  children: PropTypes.node
} : {};
